@@ -1,16 +1,16 @@
 
-from ..utils import get_indent,from_first_letter
+from ..utils import string_utils
 
 
 def docker_compose_lines(__docker_compose_src: str):
     indent, results = None, []
     for line in __docker_compose_src.splitlines(keepends=False):
-        line_indent = get_indent(line)
+        line_indent = string_utils.get_indent(line)
         if indent is None:
             if line.strip().endswith("environment:"):
                 indent = line_indent
         elif line_indent > indent:
-            ffl = from_first_letter(line)
+            ffl = string_utils.from_first_letter(line)
             if "=" in ffl:
                 results.append(ffl)
             elif ":" in ffl:
@@ -28,7 +28,7 @@ def dotenv_lines(__src: str):
 
 def dockerfile_lines(__src: str):
     return [
-        from_first_letter(line.removeprefix("ENV"))
+        string_utils.from_first_letter(line.removeprefix("ENV"))
         for line in __src.splitlines(keepends=False)
         if line.lstrip().startswith("ENV") and "=" in line
     ]
